==> zio-aws-sagemaker_3-5.17.130.7-sources.jar: zio/aws/sagemaker/model/ListModelPackagesResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class ListModelPackagesResponse(
    modelPackageSummaryList: Iterable[
      zio.aws.sagemaker.model.ModelPackageSummary
    ],
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse = {
    import ListModelPackagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
      .builder()
      .modelPackageSummaryList(modelPackageSummaryList.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly =
    zio.aws.sagemaker.model.ListModelPackagesResponse.wrap(buildAwsValue())
}
object ListModelPackagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListModelPackagesResponse =
      zio.aws.sagemaker.model.ListModelPackagesResponse(
        modelPackageSummaryList.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def modelPackageSummaryList
        : List[zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly]
    def nextToken: Option[NextToken]
    def getModelPackageSummaryList: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly
    ]] = ZIO.succeed(modelPackageSummaryList)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ) extends zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly {
    override val modelPackageSummaryList
        : List[zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly] = impl
      .modelPackageSummaryList()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.ModelPackageSummary.wrap(item)
      }
      .toList
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ): zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-5.17.203.2-sources.jar: zio/aws/sagemaker/model/ListModelPackagesResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class ListModelPackagesResponse(
    modelPackageSummaryList: Iterable[
      zio.aws.sagemaker.model.ModelPackageSummary
    ],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse = {
    import ListModelPackagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
      .builder()
      .modelPackageSummaryList(modelPackageSummaryList.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly =
    zio.aws.sagemaker.model.ListModelPackagesResponse.wrap(buildAwsValue())
}
object ListModelPackagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListModelPackagesResponse =
      zio.aws.sagemaker.model.ListModelPackagesResponse(
        modelPackageSummaryList.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def modelPackageSummaryList
        : List[zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly]
    def nextToken: Optional[NextToken]
    def getModelPackageSummaryList: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly
    ]] = ZIO.succeed(modelPackageSummaryList)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ) extends zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly {
    override val modelPackageSummaryList
        : List[zio.aws.sagemaker.model.ModelPackageSummary.ReadOnly] = impl
      .modelPackageSummaryList()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.ModelPackageSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelPackagesResponse
  ): zio.aws.sagemaker.model.ListModelPackagesResponse.ReadOnly = new Wrapper(
    impl
  )
}
